@@ -45,9 +45,10 @@ def add_hub_urls(
         or context["sourcename"].endswith(".md.txt")
     ):
         # Figure out the folders we want
-        build_dir = Path(app.outdir).parent
+        out_dir = Path(app.outdir)
+        build_dir = out_dir.parent
         ntbk_dir = build_dir.joinpath("jupyter_execute")
-        sources_dir = build_dir.joinpath("html", "_sources")
+        sources_dir = out_dir.joinpath("_sources")
         # Paths to old and new notebooks
         path_ntbk = ntbk_dir.joinpath(pagename).with_suffix(".ipynb")
         path_new_notebook = sources_dir.joinpath(pagename).with_suffix(".ipynb")
@@ -94,6 +95,7 @@ def add_hub_urls(
     jupyterhub_url = launch_buttons.get("jupyterhub_url")
     binderhub_url = launch_buttons.get("binderhub_url")
     colab_url = launch_buttons.get("colab_url")
+    deepnote_url = launch_buttons.get("deepnote_url")
     if binderhub_url:
         url = (
             f"{binderhub_url}/v2/gh/{org}/{repo}/{branch}?"
@@ -112,6 +114,11 @@ def add_hub_urls(
         url = f"{colab_url}/github/{org}/{repo}/blob/{branch}/{path_rel_repo}"
         context["colab_url"] = url
 
+    if deepnote_url:
+        github_path = f"%2F{org}%2F{repo}%2Fblob%2F{branch}%2F{path_rel_repo}"
+        url = f"{deepnote_url}/launch?url=https%3A%2F%2Fgithub.com{github_path}"
+        context["deepnote_url"] = url
+
     # Add thebe flag in context
     if launch_buttons.get("thebe", False):
         context["use_thebe"] = True
